@@ -25,7 +25,7 @@ except ImportError:
 
 if is_py2:
     from urllib import urlencode, quote_plus
-    from urlparse import parse_qsl
+    from urlparse import parse_qsl, urlsplit
 
     str = unicode
     basestring = basestring
@@ -33,7 +33,7 @@ if is_py2:
 
 
 elif is_py3:
-    from urllib.parse import urlencode, quote_plus, parse_qsl
+    from urllib.parse import urlencode, quote_plus, parse_qsl, urlsplit
 
     str = str
     basestring = (str, bytes)
